#!/bin/bash
#------------------------------------------------------------------------------
set -u

# Usage: 
# bootstrap-linux.sh [<SDPBranch>]
# The <SDPBranch> parameter is optional.  SDPBranch determines
# the branch of the SDP to test with, 'main' by default but can
# be 'dev'.

# Bootstraps a new Linux server with requirements Helix Installer testing.

function msg () { echo -e "$*"; }
function bail () { msg "\\nError: ${1:-Unknown Error}\\n"; exit "${2:-1}"; }

declare Version=1.5.2
declare SDPBranch=${1:-main}
declare HelixInstallerArgs=

msg "Starting ${0##*/} v$Version at $(date)."

# Currently, RHEL/CentOS and Ubuntu flavors are supported.
# See release notes for more specific details of which versions are
# currently supported.
if [[ -r "/etc/redhat-release" ]]; then
   msg "Verified: Running Red Hat or similar Linux OS."
elif [[ -r "/etc/lsb-release" ]]; then
   msg "Verified: Running Ubuntu or similar Linux OS."
else
   msg "Warning: Running on unknown OS. Hoping for the best."
fi

if [[ -d /hxdepots/test-reset ]]; then
   [[ -d /hxdepots/reset ]] && \
      bail "Directory /hxdepots/reset unexpectedly exists at bootstrap!"

   if [[ -d /hxdepots ]]; then
      msg "Using existing /hxdepots volume provisioned at bootstrap."
   else
      msg "Initializing /hxdepots dir."
      sudo mkdir /hxdepots
   fi

   msg "Testing files from local workspace."
   sudo cp -pr /hxdepots/test-reset /hxdepots/reset
   cd /hxdepots/reset || bail "Failed to do 'cd /hxdepots/reset'. Aborting."
else
   bail "Expected test support dir /hxdepots/test-reset does not exist. Check the Vagrantfile for the setting 'machine.vm.synced_folder'."
fi

HelixInstallerVersion=$(grep '^declare Version=' reset_sdp.sh)
HelixInstallerVersion=${HelixInstallerVersion#declare }
msg "Helix Installer version: $HelixInstallerVersion"

HelixInstallerCmd="./reset_sdp.sh"
HelixInstallerArgs="-fast -b $SDPBranch"
#HelixInstallerArgs="-b $SDPBranch"
msg "Calling Helix Installer: $HelixInstallerCmd"
#shellcheck disable=SC2086,SC2024
sudo $HelixInstallerCmd $HelixInstallerArgs > log.reset_sdp.txt 2>&1
